import type { LRParser } from '@lezer/lr';
export interface HighlightOptions {
    from?: number;
    to?: number;
}
export interface HighlightResult {
    color: string;
    segment: string;
}
export interface Highlighter {
    (code: string, options?: HighlightOptions): HighlightResult[];
}
export declare function highlight(parser: LRParser, code: string, options?: HighlightOptions): {
    color: string;
    segment: string;
}[];
export declare function highlightLines(code: string, highlightLanguage: Highlighter): HighlightResult[][];
declare const SUPPORTED_LANGUAGES: {
    readonly cpp: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly css: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly html: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly json: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly python: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly rust: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly svelte: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly noop: () => Promise<Highlighter>;
    readonly plaintext: () => Promise<Highlighter>;
    readonly txt: () => Promise<Highlighter>;
    readonly text: () => Promise<Highlighter>;
    readonly javascript: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly js: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly jsx: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly typescript: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly ts: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
    readonly tsx: () => Promise<(code: string, options?: HighlightOptions | undefined) => {
        color: string;
        segment: string;
    }[]>;
};
export type HighlightLanguage = keyof typeof SUPPORTED_LANGUAGES;
export declare function isSupportedLanguage(language: unknown): language is HighlightLanguage;
export declare function getHighlighter(language: HighlightLanguage): Promise<Highlighter>;
export declare function getSupportedHighlighter(language?: string | null): Promise<Highlighter>;
export {};
